##############################
@{{ program }}@ - TIS analysis
##############################

TIS analysis report generated by @{{ program }}@ version @{{ version }}@
on @{{ date }}@.

Please note that the flux (and thus the rate constant)
was **not** calculated in this analysis!

The main result is:

* The crossing probability:
  :math:`P_{\text{cross}} = @{{ numbers['pcross'] }}@  \pm  @{{ numbers['perr'] }}@ \%`

.. _combined-results:

Combined results
================

The overall matched probability distributions are shown in the left figure
while the matched probability distribution is shown in the right figure below.
The overall crossing probability as a function of cycles
and its relative error block analysis are reported in the two following
plots, respectively.

.. image:: @{{ figures['total'] }}@
   :width: 45%
.. image:: @{{ figures['matched']}}@
   :width: 45%

.. image:: @{{ figures['progress'] }}@
   :width: 45%
.. image:: @{{ figures['error']}}@
   :width: 45%

Detailed results are given below for the different path
ensembles.

.. _figure-results:

Results for path ensembles
==========================

The following interfaces were used in the simulation and in
the analysis:

@{{ tables['interfaces'] }}@

@{{ tables['probability'] }}@

@{{ tables['efficiency'] }}@

The crossing probabilities are also displayed in the figures below

.. _prob-figures-output:

Crossing probabilities
----------------------

@{% for figure in figures['tis'] %}@
.. image:: @{{ figure['pcross'] }}@
   :width: 30%
.. image:: @{{ figure['prun'] }}@
   :width: 30%
.. image:: @{{ figure['perror'] }}@
   :width: 30%
@{% endfor %}@


.. _len-shoot-figures-output:

Distributions for path lengths and shooting moves
-------------------------------------------------

The average path lengths in the different ensembles are given in
the table below and some distributions for the path lengths and
shooting moves can also be found here:

@{% for figure in figures['tis'] %}@
.. image:: @{{ figure['lpath'] }}@
   :width: 45%
.. image:: @{{ figure['shoots'] }}@
   :width: 45%
@{% endfor %}@



